==> haskell-prettyprinter-1.2.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.2.1
id: prettyprinter-1.2.1-KiYg8gkPUWOHZVQZ6fFalX
key: prettyprinter-1.2.1-KiYg8gkPUWOHZVQZ6fFalX
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: f24fdbcb7c2c0761779566f12174e500
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-1.2.1
hs-libraries: HSprettyprinter-1.2.1-KiYg8gkPUWOHZVQZ6fFalX
depends:
    base-4.11.1.0 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-1.2.1-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter
version: 1.2.1
id: prettyprinter-1.2.1-Gcqbuk4agk3F3rKgzFN7Y3
key: prettyprinter-1.2.1-Gcqbuk4agk3F3rKgzFN7Y3
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: Phil Wadler, Daan Leijen, Max Bolingbroke, Edward Kmett, David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: A modern, easy to use, well-documented, extensible pretty-printer.
description:
    A modern, easy to use, well-documented, extensible pretty-printer. For more see README.md
category: User Interfaces, Text
abi: a81bab60ee188ba8c6b2c32086f457f0
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc Data.Text.Prettyprint.Doc.Internal
    Data.Text.Prettyprint.Doc.Internal.Type
    Data.Text.Prettyprint.Doc.Render.ShowS
    Data.Text.Prettyprint.Doc.Render.String
    Data.Text.Prettyprint.Doc.Render.Text
    Data.Text.Prettyprint.Doc.Render.Tutorials.StackMachineTutorial
    Data.Text.Prettyprint.Doc.Render.Tutorials.TreeRenderingTutorial
    Data.Text.Prettyprint.Doc.Render.Util.Panic
    Data.Text.Prettyprint.Doc.Render.Util.SimpleDocTree
    Data.Text.Prettyprint.Doc.Render.Util.StackMachine
    Data.Text.Prettyprint.Doc.Symbols.Ascii
    Data.Text.Prettyprint.Doc.Symbols.Unicode
    Data.Text.Prettyprint.Doc.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/prettyprinter-1.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/prettyprinter-1.2.1
hs-libraries: HSprettyprinter-1.2.1-Gcqbuk4agk3F3rKgzFN7Y3
depends:
    base-4.11.1.0 text-1.2.3.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
haddock-interfaces: /usr/share/doc/haskell-prettyprinter/html/prettyprinter.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
